@@ -682,15 +682,15 @@ CameraPTZDelegateMethodNames = Literal["moveAbsolute", "moveRelative", "moveCont
 
 class CameraMotionDetectionDelegate(metaclass=ABCMeta):
     @abstractmethod
-    async def detectImage(self, image: bytes) -> list[Detection]: ...
+    async def detectVideo(self, video_path: str) -> list[Detection]: ...
 
 
-CameraMotionDetectionDelegateMethodNames = Literal["detectImage"]
+CameraMotionDetectionDelegateMethodNames = Literal["detectVideo"]
 
 
 class CameraObjectDetectionDelegate(metaclass=ABCMeta):
     @abstractmethod
-    async def detectImage(self, image: bytes) -> list[Detection]: ...
+    async def detectImage(self, image: bytes, metadata: "ImageMetadata") -> list[Detection]: ...
 
 
 CameraObjectDetectionDelegateMethodNames = Literal["detectImage"]
@@ -753,6 +753,12 @@ class IceServer(TypedDict):
 DecoderFormat = Literal["yuv", "rgb"]
 
 
+class ImageMetadata(TypedDict):
+    width: int
+    height: int
+    format: Literal["rgb"]
+
+
 class FrameMetadata(TypedDict):
     format: DecoderFormat
     frameSize: float
@@ -860,23 +866,21 @@ class CameraDevice(Protocol):
     objectDetectorDelegate: CameraObjectDetectionDelegate
 
     @overload
-    async def set_delegate(self, name: Literal["cameraDelegate"], delegate: CameraDelegate) -> None: ...
+    def set_delegate(self, name: Literal["cameraDelegate"], delegate: CameraDelegate) -> None: ...
     @overload
-    async def set_delegate(
-        self, name: Literal["prebufferDelegate"], delegate: CameraPrebufferDelegate
-    ) -> None: ...
+    def set_delegate(self, name: Literal["prebufferDelegate"], delegate: CameraPrebufferDelegate) -> None: ...
     @overload
-    async def set_delegate(self, name: Literal["ptzDelegate"], delegate: CameraPTZDelegate) -> None: ...
+    def set_delegate(self, name: Literal["ptzDelegate"], delegate: CameraPTZDelegate) -> None: ...
     @overload
-    async def set_delegate(
+    def set_delegate(
         self, name: Literal["audioDetectorDelegate"], delegate: CameraAudioDetectionDelegate
     ) -> None: ...
     @overload
-    async def set_delegate(
+    def set_delegate(
         self, name: Literal["motionDetectorDelegate"], delegate: CameraMotionDetectionDelegate
     ) -> None: ...
     @overload
-    async def set_delegate(
+    def set_delegate(
         self, name: Literal["objectDetectorDelegate"], delegate: CameraObjectDetectionDelegate
     ) -> None: ...
 
